@@ -47,6 +47,9 @@ effects['Normalize'] = mkfx_overwrite_selection(normalize)
 effects['Negate'] = mkfx_overwrite_selection(negate)
 effects['Fade In'] = mkfx_overwrite_selection(fade)
 effects['Fade Out'] = mkfx_overwrite_selection(fade_out)
+import fx.monoize
+import fx.volume
+import fx.svf
 
 # Tests
 if __name__ == '__main__':
