@@ -70,7 +70,7 @@ class EditorWindow(gtk.Window):
         self.waveform = GraphView(graph, selection, cursor)
         self.scrollbar = GraphScrollbar(graph)
         self.statusbar = gtk.Statusbar()
-        self.filedialog = FileDialog(app.list_extensions())
+        self.filedialog = FileDialog(app.list_extensions(), self)
 
         self.vbox = gtk.VBox()
         self.vbox.pack_start(self.menubar, expand=False, fill=False)
@@ -148,6 +148,7 @@ class EditorWindow(gtk.Window):
               <toolitem action="Start"/>
               <toolitem action="Stop"/>
               <toolitem action="Play"/>
+              <toolitem action="End"/>
               <separator/>
               <toolitem action="Cut"/>
               <toolitem action="Copy"/>
@@ -321,7 +322,9 @@ class EditorWindow(gtk.Window):
     
     @busy
     def effect(self, widget, *args):
-        self.ctrl.effect(*args)
+        dialog = self.ctrl.effect(*args)
+        if dialog:
+            dialog(self)
 
     def about(self, *args):
         d = gtk.AboutDialog()
